MCD ternary_unicity
Disponibilité ( #semaine, voilier )

- Le champ semaine fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Semaine pour renforcer l'identifiant.
- Le champ voilier fait partie de la clé primaire de la table. Il a migré à partir de l'entité Voilier pour renforcer l'identifiant. Cependant, comme la table créée à partir de cette entité a été supprimée, il n'est pas considéré comme clé étrangère.

Réservation ( id résa, num résa u1, arrhes, date réservation, #semaine u2, #voilier u2 )

- Le champ id résa constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Réservation.
- Le champ num résa était déjà un simple attribut de l'entité Réservation. Il obéit à la contrainte d'unicité 1.
- Les champs arrhes et date réservation étaient déjà de simples attributs de l'entité Réservation.
- Les champs semaine et voilier sont des clés étrangères. Ils ont migré par l'association de dépendance fonctionnelle DF à partir de l'entité Disponibilité en perdant leur caractère identifiant. Ils obéissent en outre à la contrainte d'unicité 2.

Semaine ( semaine, date début u1 )

- Le champ semaine constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Semaine.
- Le champ date début était déjà un simple attribut de l'entité Semaine. Il obéit à la contrainte d'unicité 1.

NB. La table Voilier a été supprimée car elle était réduite à la clé primaire de son entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.